@@ -43,5 +43,5 @@ struct _Arrow {
 
 Arrow *arrow_get(ArrowType type);
 void   arrow_draw(ArrowType type, int x, int y);
-int    arrow_draw_all(Player *player);
+void   arrow_draw_all(Player *player);
 #endif
