@@ -33,10 +33,17 @@ struct _Game
 	int first_avail_spot;
 	int started;
 	int cur_player, cur_x, cur_y;
-	int move_id, waiting;
+	int move_id;
+	int waiting_acks;
 	int quit_players;
 	int killed;
 	int last_joined;
+
+#ifndef __MINGW32__
+	pthread_cond_t  cond_wait;
+	pthread_cond_t  cond_move;
+	pthread_cond_t  cond_quit;
+#endif
 };
 
 void game_free(Game *);
