@@ -19,11 +19,11 @@
 
 /**
  * Biloba - Q1 2005
-	* Game by Guillaume Demougeot <dmgt@wanadoo.fr>
-	* Code by Colin Leroy <colin@colino.net>
-	*
-	* This file contains all the network client code.
-	*/
+ * Game by Guillaume Demougeot <dmgt@wanadoo.fr>
+ * Code by Colin Leroy <colin@colino.net>
+ *
+ * This file contains all the network client code.
+ */
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -39,6 +39,7 @@
 
 #include <SDL.h>
 #include <SDL_thread.h>
+#include <SDL_mutex.h>
 #include <string.h>
 
 #include "utils.h"
@@ -200,7 +201,7 @@ int sock_connect(const char *hostname, unsigned short port)
 
 #define CHECK_MSG(str) {				\
 	read_msg(mysock, buf, 255, &len);		\
-	buf[254] = '\0';					\
+	buf[254] = '\0';				\
 	if (strncmp(buf, str, strlen(str))) {		\
 		printf("Unexpected reply \"%s\"",	\
 			buf);				\
@@ -289,11 +290,12 @@ int net_init_game(const char *gamename, int numplayers,
 	return mygameid;
 	
 err_protocol:
-		close(mysock);
+	printf("closing.\n");
+	close(mysock);
 err_socket:
-		mysock = INVSOCK;
-		mygameid = -1;
-		return -1;
+	mysock = INVSOCK;
+	mygameid = -1;
+	return -1;
 }
 
 static SDL_Thread *kb_thread = NULL;
@@ -332,6 +334,10 @@ int net_wait_ready(int num_players, char **player_names)
 	char buf[255], player[255];
 	int nplayer, i;
 	int tmp = 0;
+	
+	if (mysock == INVSOCK)
+		return -1;
+
 #ifndef __MINGW32__
 	assert(mysock > 0);
 #else
@@ -462,7 +468,7 @@ err_socket:
 	return NULL;
 }
 
-void net_get_info(Game *game)
+int net_get_info(Game *game)
 {
 	int gameid = htonl(game->id);
 	char buf[255];
@@ -471,6 +477,8 @@ void net_get_info(Game *game)
 
 	printf("PRELJOIN: sock %d\n", mysock);
 
+	if (mysock == INVSOCK)
+		return -1;
 #ifndef __MINGW32__
 	assert(mysock > 0);
 #else
@@ -489,7 +497,7 @@ void net_get_info(Game *game)
 	if (!strncmp(buf, "ERROR1", 6)) {
 		close(mysock);
 		mysock = INVSOCK;
-		return;
+		return -1;
 	}
 
 	for (i = 0; i < game->num_players; i++) {
@@ -504,15 +512,19 @@ void net_get_info(Game *game)
 	tmp = ntohl(tmp);
 	printf("PRELJOIN< %d (first avail spot)\n", tmp);
 	game->first_avail_spot = tmp;
-
+	
+	return 0;
 }
 
-void net_join(int id, int nump, char *my_player_name)
+int net_join(int id, int nump, char *my_player_name)
 {
 	char buf[255];
 	unsigned char len;
 	int mid = htonl(nump);
 
+	if (mysock == INVSOCK)
+		return -1;
+
 	printf("JOIN: sock %d\n", mysock);
 #ifndef __MINGW32__
 	assert(mysock > 0);
@@ -530,11 +542,13 @@ void net_join(int id, int nump, char *my_player_name)
 	if (strncmp(buf, "OK", 2)) {
 		close(mysock);
 		mysock = INVSOCK;
-		return;
+		return -1;
 	}
 	
 	send_msg(mysock, my_player_name, strlen(my_player_name) + 1);
 	printf("JOIN> %s (my name)\n", my_player_name);
+	
+	return 0;
 }
 
 void net_send_event(int player, int x, int y)
@@ -559,12 +573,14 @@ void net_send_event(int player, int x, int y)
 }
 
 static SDL_Thread *screen_thread = NULL;
+static SDL_sem *screen_thread_sem = NULL;
+
 static int run_screen_thread = FALSE;
 static int screen_repaint(void *data)
 {
 	while (run_screen_thread) {
 		SDL_UpdateRect(screen, 0, 0, 0, 0);
-		SDL_Delay(1000);
+		SDL_SemWaitTimeout(screen_thread_sem, 1000);
 	}
 	return 0;
 }
@@ -582,6 +598,7 @@ void net_get_event(int player, int *x, int *y)
 		return;
 #endif
 	run_screen_thread = TRUE;
+	screen_thread_sem = SDL_CreateSemaphore(1);
 	screen_thread = SDL_CreateThread(screen_repaint, NULL);
 	send_msg(mysock, &cmd, 1);
 	tmp = htonl(player);
@@ -592,6 +609,7 @@ void net_get_event(int player, int *x, int *y)
 		*x = -2;
 		*y = -2;
 	} else {
+		SDL_SemPost(screen_thread_sem);
 		tmp_x = ntohl(tmp_x);
 		tmp_y = ntohl(tmp_y);
 		*x = tmp_x;
@@ -599,6 +617,7 @@ void net_get_event(int player, int *x, int *y)
 	}
 	run_screen_thread = FALSE;
 	SDL_WaitThread(screen_thread, &tmp);
+	SDL_DestroySemaphore(screen_thread_sem);
 }
 
 void net_end_game(int player)
@@ -639,7 +658,6 @@ const char *net_get_server(void)
 
 void net_set_server(const char *srv)
 {
-	if (server)
-		free(server);
+	free(server);
 	server = srv ? strdup(srv):NULL ;
 }
