@@ -34,8 +34,8 @@ int net_init_game(const char *gamename, int numplayers,
 		  InputSystemMethod p3method, const char *p3name);
 int net_wait_ready(int num_players, char **player_names);
 LList *net_get_games(int numplayer);
-void net_get_info(Game *game);
-void net_join(int id, int nump, char *my_player_name);
+int net_get_info(Game *game);
+int net_join(int id, int nump, char *my_player_name);
 void net_send_event(int player, int x, int y);
 void net_get_event(int player, int *x, int *y);
 void net_end_game(int player);
