@@ -19,11 +19,11 @@
 
 /**
  * Biloba - Q1 2005
-	* Game by Guillaume Demougeot <dmgt@wanadoo.fr>
-	* Code by Colin Leroy <colin@colino.net>
-	*
-	* This file contains all pawn management code.
-	*/
+ * Game by Guillaume Demougeot <dmgt@wanadoo.fr>
+ * Code by Colin Leroy <colin@colino.net>
+ *
+ * This file contains all pawn management code.
+ */
 
 #include <SDL.h>
 #include <SDL_image.h>
@@ -74,7 +74,7 @@ static LList *my_pawns = NULL;
 static void init_pawns_models(void)
 {
 	int i = 0;
-	assert(pawns_models[PAWN_NUM_COLORS] == NULL);
+	assert(pawns_models[0] == NULL);
 	
 	pawns_models[PAWN_ORANGE] = biloba_load_image("pawn-orange.png");
 	pawns_models[PAWN_BLUE]   = biloba_load_image("pawn-blue.png");
@@ -347,8 +347,9 @@ void pawn_move_to(Pawn *pawn, Tile *tile)
 
 LList *pawn_get_replacement_pending_pawns(PawnColor color)
 {
-	LList *results = NULL, *cur = pawn_get_all(color);
-	
+	LList *results = NULL, *all = pawn_get_all(color);
+	LList *cur = all;
+
 	while (cur) {
 		Pawn *pawn = (Pawn *)cur->data;
 		if (pawn->just_ate_on) {
@@ -379,6 +380,8 @@ LList *pawn_get_replacement_pending_pawns(PawnColor color)
 		cur = cur->next;
 	}
 	
+	llist_free(all);
+
 	return results;
 }
 
